----------------------
pDebuffList = AceLibrary("AceAddon-2.0"):new("AceEvent-2.0", "AceDB-2.0")
local Aura = nil
local BS = AceLibrary("Babble-Spell-2.2")
local L = AceLibrary("AceLocale-2.2"):new("pDebuffList")
local addon = pDebuffList
local font = GameFontNormal:GetFont()

L:RegisterTranslations( "enUS", function() return {
		["DS"] = true,
		["TC"] = true,
		["TF"] = true,
		["SA"] = true,
		["CoE"] = true,
		["CoS"] = true,
		["CoR"] = true,
		["CoW"] = true,
		["FF"] = true,
		["DR"] = true,
	} end )

L:RegisterTranslations( "deDE", function() return {
		["DS"] = "DR",
		["TC"] = "DK",
		["SA"] = "RZ",
		["CoE"] = "FdE",
		["CoS"] = "FdS",
		["CoR"] = "FdT",
	} end )
	

local debuffs = {
	BS["Demoralizing Shout"],
	BS["Thunder Clap"],
	BS["Sunder Armor"],
	BS["Curse of the Elements"],
	BS["Curse of Shadow"],
	BS["Curse of Recklessness"],
	BS["Faerie Fire"],
}

local optDebuffs = {
	[BS["Thunder Clap"]] = { BS["Thunderfury"] },
	[BS["Faerie Fire"]] = { BS["Faerie Fire (Feral)"] },
	[BS["Demoralizing Shout"]] = { BS["Curse of Weakness"], BS["Demoralizing Roar"] }
}

local shortDebuff = {
	[BS["Demoralizing Shout"]] = L["DS"],
	[BS["Thunder Clap"]] = L["TC"],
	[BS["Thunderfury"]] = L["TF"],
	[BS["Sunder Armor"]] = L["SA"],
	[BS["Curse of Weakness"]] = L["CoW"],
	[BS["Curse of the Elements"]] = L["CoE"],
	[BS["Curse of Shadow"]] = L["CoS"],
	[BS["Curse of Recklessness"]] = L["CoR"],
	[BS["Faerie Fire"]] = L["FF"],
	[BS["Faerie Fire (Feral)"]] = L["FF"],
	[BS["Demoralizing Roar"]] = L["DR"],
}
----------------------

----------------------
function addon:OnInitialize()
	self:RegisterDB("PDLDB", "PDLPerCharDB")
end
----------------------

----------------------
function addon:OnEnable()
	self:RegisterBucketEvent("UNIT_AURA", 0.2, "DebuffListCheck")
	self:RegisterEvent("PLAYER_FOCUS_CHANGED", "DebuffListCheck")
	self:RegisterEvent("PLAYER_TARGET_CHANGED", "DebuffListCheck")
	if not Aura then
		Aura = AceLibrary("SpecialEvents-Aura-2.0")
	end
	self:CreateFrame()
	self:DebuffListCheck()
	self:RestorePosition()
end
----------------------

----------------------
function addon:CreateFrame()

	if self.frame then
		return
	end

	local f = CreateFrame("Frame", "pDebuffListFrame", UIParent)
	self.frame = f

	f:SetBackdrop({
		bgFile = "Interface\\ChatFrame\\ChatFrameBackground", tile = true, tileSize = 16,
		edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border", edgeSize = 16,
		insets = {left = 4, right = 4, top = 4, bottom = 4},
	})

	f:SetWidth(64)
	f:SetHeight(90)
	f:EnableMouse(true)
	f:SetMovable(true)
	f:RegisterForDrag"LeftButton"
	f:SetScript("OnDragStart", function() if IsAltKeyDown() then this:StartMoving() end end)
	f:SetScript("OnDragStop", function() this:StopMovingOrSizing() self:SavePosition() end)

	f:SetBackdropColor(0, 0, 0)
	f:SetBackdropBorderColor(0, 0, 0)
	f:SetPoint("CENTER", UIParent)

	f.focus = {}
	f.target = {}
	local ff = f:CreateFontString(nil,"OVERLAY")
	f.target.header = ff
	ff:SetFont(font, 11)
	ff:SetWidth(27)
	ff:SetHeight(15)
	ff:SetText("T")
	ff:SetJustifyH("CENTER")
	ff:ClearAllPoints()
	ff:SetPoint("TOPLEFT", f, "TOPLEFT", 4, -2 )

	ff = f:CreateFontString(nil,"OVERLAY")
	f.focus.header = ff
	ff:SetFont(font, 11)
	ff:SetWidth(27)
	ff:SetHeight(15)
	ff:SetText("F")
	ff:SetJustifyH("CENTER")
	ff:ClearAllPoints()
	ff:SetPoint("TOPRIGHT", f, "TOPRIGHT", -4, -2 )
	
	for k, debuff in ipairs( debuffs ) do

		local offset = -2 - (k * 10)

		ff = f:CreateFontString(nil,"OVERLAY")
		f.target[debuff] = ff
		ff:SetFont(font, 11)
		ff:SetWidth(27)
		ff:SetHeight(15)
		ff:SetText("")
		ff:SetJustifyH("CENTER")
		ff:ClearAllPoints()
		ff:SetPoint("TOPLEFT", f, "TOPLEFT", 4, offset )
		
		ff = f:CreateFontString(nil,"OVERLAY")
		f.focus[debuff] = ff
		ff:SetFont(font, 11)
		ff:SetWidth(27)
		ff:SetHeight(15)
		ff:SetText("")
		ff:SetJustifyH("CENTER")
		ff:ClearAllPoints()
		ff:SetPoint("TOPRIGHT", f, "TOPRIGHT", -4, offset )		
		
	end

	f:Show()
end
----------------------

----------------------
function addon:DebuffListCheck()
	local f = self.frame
	if GetNumRaidMembers() > 0 then
		if ( UnitExists("focus") and not UnitIsPlayer("focus") ) or ( UnitExists("target") and not UnitIsPlayer("target") ) then
			f:Show()
			local optdebuff
			for k, debuff in ipairs( debuffs ) do
				optdebuff = optDebuffs[debuff]
				self:UpdateDebuff("target", debuff, optdebuff)
				self:UpdateDebuff("focus", debuff, optdebuff)
			end
		else
			f:Hide()
		end
	else
		f:Hide()
	end
end
----------------------

----------------------

function addon:UpdateDebuff( unit, debuff, optdebuff )
	local text
	if UnitExists(unit) and not UnitIsPlayer(unit) then
		text = "|cffff0000"..shortDebuff[debuff].."|r"
		if Aura:UnitHasDebuff(unit, debuff) then
			text = "|cff00ff00"..shortDebuff[debuff].."|r"
		elseif optdebuff then
			for k, optd in ipairs( optdebuff ) do
				if Aura:UnitHasDebuff(unit, optd) then
					text = "|cff00ff00"..shortDebuff[optd].."|r"
					break
				end
			end
		end
	else
		text = "|cffaaaaaaN/A|r"
	end
	self.frame[unit][debuff]:SetText( text )
end
----------------------

----------------------
function addon:SavePosition()

	local f = self.frame

	self.db.profile.posx = f:GetLeft()
	self.db.profile.posy = f:GetTop()

end
---------------------

---------------------
function addon:RestorePosition()

    local f = self.frame
	local x = self.db.profile.posx
	local y = self.db.profile.posy

	if not x or not y then return end

	f:ClearAllPoints()
	f:SetPoint("TOPLEFT", UIParent, "BOTTOMLEFT", x, y)

end
---------------------